@@ -47,7 +47,9 @@ if ($checkContent != '') {
     $keywords = strtolower($keywords);
     $keywords = strip_tags(str_replace('"','',$keywords));
     $keywords = preg_replace('/{.*}/','',$keywords);
-    $keywords = preg_replace(array('/&[^\s]*;/'), '', htmlentities($keywords));
+    $keywords = preg_replace(array('/&[^\s]*;/'), '', $keywords);
+    $keywords = htmlentities($keywords, ENT_COMPAT, 'UTF-8');
+    $keywords = utf8_encode(html_entity_decode($keywords));
 }
 
 if ($keywords != '') {
@@ -130,7 +132,7 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desc = strip_tags(str_replace('"','',$desc));
     $desc = preg_replace('/{.*}/','',$desc);
     $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
-    $desc = htmlentities($desc, ENT_IGNORE, 'UTF-8');
+    $desc = htmlentities($desc, ENT_COMPAT, 'UTF-8');
     $desc = utf8_encode(html_entity_decode($desc));
 } elseif ($this->GetPreference('auto_title','1') == 1 && $curcontent->GetPropertyValue($description_block) == '') {
     $desc = $curcontent->GetPropertyValue('content_en');
@@ -138,7 +140,9 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desc = str_replace('><','> <',$desc);
     $desc = strip_tags(str_replace('"','',$desc));
     $desc = preg_replace('/{.*}/','',$desc);
-    $desc = preg_replace(array('/&[^\s]*;/'), '', htmlentities($desc));
+    $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
+    $desc = htmlentities($desc, ENT_COMPAT, 'UTF-8');
+    $desc = utf8_encode(html_entity_decode($desc));
     $desclength = $this->GetPreference('length_title','30');
     $desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
 } elseif ($this->GetPreference('auto_title','1') == 1) {
@@ -147,7 +151,9 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desc = str_replace('><','> <',$desc);
     $desc = strip_tags(str_replace('"','',$desc));
     $desc = preg_replace('/{.*}/','',$desc);
-    $desc = preg_replace(array('/&[^\s]*;/'), '', htmlentities($desc));
+    $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
+    $desc = htmlentities($desc, ENT_COMPAT, 'UTF-8');
+    $desc = utf8_encode(html_entity_decode($desc));
     $desclength = $this->GetPreference('length_title','30');
     $desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
 } else {
