@@ -8,6 +8,12 @@ if (! $this->CheckPermission('Use MetaMax')) {
 $this->SetPreference('analyticstype_title', $params['analyticstype_title']);
 $this->SetPreference('propertyid_title', $params['propertyid_title']);
 $this->SetPreference('webmasterid_title', $params['webmasterid_title']);
+$this->SetPreference('pretty_title',
+		     (isset($params['pretty_title'])?'1':'0'));
+$this->SetPreference('post_title',
+		     (isset($params['post_title'])?'1':'0'));
+$this->SetPreference('query_title', $params['query_title']);
+$this->SetPreference('results_title', $params['results_title']);
 $this->SetPreference('bingid_title', $params['bingid_title']);
 
 $params = array('tab_message'=> 'prefsupdated', 'active_tab' => 'analytics');
